/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import {fetch, openToast} from 'frontend-js-web';

import {
	HEADLESS_BATCH_PLANNER_URL,
	TEMPLATE_SELECTED_EVENT,
} from '../constants';

export async function fetchTemplateDetails(templateId) {
	if (!templateId) {
		return Liferay.fire(TEMPLATE_SELECTED_EVENT, {
			template: null,
		});
	}

	try {
		const request = await fetch(
			`${HEADLESS_BATCH_PLANNER_URL}/plans/${templateId}`
		);

		if (!request.ok) {
			throw new Error();
		}

		return await request.json();
	}
	catch (error) {
		openToast({
			message: Liferay.Language.get('unexpected-error'),
			type: 'danger',
		});
	}
}
